package com.zkqy.system.service.impl;

import java.util.List;

import com.zkqy.common.utils.DateUtils;
import com.zkqy.system.entity.DragTree;
import com.zkqy.system.mapper.DragTreeMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zkqy.system.service.IDragTreeService;

/**
 * 拖拽树结构Service业务层处理
 * 
 * @author hmc
 * @date 2025-03-05
 */
@Service
public class DragTreeServiceImpl implements IDragTreeService
{
    @Autowired
    private DragTreeMapper dragTreeMapper;

    /**
     * 查询拖拽树结构
     * 
     * @param id 拖拽树结构主键
     * @return 拖拽树结构
     */
    @Override
    public DragTree selectDragTreeById(Long id)
    {
        return dragTreeMapper.selectDragTreeById(id);
    }

    /**
     * 查询拖拽树结构列表
     * 
     * @param dragTree 拖拽树结构
     * @return 拖拽树结构
     */
    @Override
    public List<DragTree> selectDragTreeList(DragTree dragTree)
    {
        return dragTreeMapper.selectDragTreeList(dragTree);
    }

    /**
     * 新增拖拽树结构
     * 
     * @param dragTree 拖拽树结构
     * @return 结果
     */
    @Override
    public int insertDragTree(DragTree dragTree)
    {
        dragTree.setCreateTime(DateUtils.getNowDate());
        return dragTreeMapper.insertDragTree(dragTree);
    }

    /**
     * 修改拖拽树结构
     * 
     * @param dragTree 拖拽树结构
     * @return 结果
     */
    @Override
    public int updateDragTree(DragTree dragTree)
    {
        dragTree.setUpdateTime(DateUtils.getNowDate());
        return dragTreeMapper.updateDragTree(dragTree);
    }

    /**
     * 批量删除拖拽树结构
     * 
     * @param ids 需要删除的拖拽树结构主键
     * @return 结果
     */
    @Override
    public int deleteDragTreeByIds(Long[] ids)
    {
        return dragTreeMapper.deleteDragTreeByIds(ids);
    }

    /**
     * 删除拖拽树结构信息
     * 
     * @param id 拖拽树结构主键
     * @return 结果
     */
    @Override
    public int deleteDragTreeById(Long id)
    {
        return dragTreeMapper.deleteDragTreeById(id);
    }
}
