package com.zkqy.system.service.impl;

import java.util.List;

import com.zkqy.common.utils.StringUtils;
import com.zkqy.system.entity.MobilePageData;
import com.zkqy.system.entity.MobilePageTableList;
import com.zkqy.system.mapper.MobilePageTableListMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zkqy.system.mapper.MobilePageDataMapper;
import com.zkqy.system.service.IMobilePageDataService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 移动端数据Service业务层处理
 * 
 * @author zkqy
 * @date 2024-04-18
 */
@Service
public class MobilePageDataServiceImpl implements IMobilePageDataService 
{
    @Autowired
    private MobilePageDataMapper mobilePageDataMapper;

    @Autowired
    private MobilePageTableListMapper mobilePageTableListMapper;
    /**
     * 查询移动端数据
     * 
     * @param id 移动端数据主键
     * @return 移动端数据
     */
    @Override
    public MobilePageData selectMobilePageDataById(Long id)
    {
        MobilePageData mobilePageData = mobilePageDataMapper.selectMobilePageDataById(id);
        if(mobilePageData.getIsExistsList().equals("true")){
            MobilePageTableList mobilePageTableList = mobilePageTableListMapper.selectMobilePageTableListByPageId(mobilePageData.getId());
            mobilePageData.setMobilePageTableList(mobilePageTableList);
        }
        return mobilePageData;
    }

    /**
     * 查询移动端数据列表
     * 
     * @param mobilePageData 移动端数据
     * @return 移动端数据
     */
    @Override
    public List<MobilePageData> selectMobilePageDataList(MobilePageData mobilePageData)
    {
        return mobilePageDataMapper.selectMobilePageDataList(mobilePageData);
    }

    /**
     * 新增移动端数据
     * 
     * @param mobilePageData 移动端数据
     * @return 结果
     */
    @Override
    @Transactional
    public int insertMobilePageData(MobilePageData mobilePageData)
    {
        mobilePageData.setIsIndex("false");
        String isExistsList = mobilePageData.getIsExistsList();
        int i = mobilePageDataMapper.insertMobilePageData(mobilePageData);
        if(StringUtils.isNotNull(isExistsList)&&isExistsList.equals("true")){ //如果存在list集合页面就新增list表格数据
            mobilePageData.getMobilePageTableList().setPageId(mobilePageData.getId());
            mobilePageTableListMapper.insertMobilePageTableList(mobilePageData.getMobilePageTableList());
        }
        //测试这里有问题嘛?
        return 1;
    }

    /**
     * 修改移动端数据
     * 
     * @param mobilePageData 移动端数据
     * @return 结果
     */
    @Override
    @Transactional
    public int updateMobilePageData(MobilePageData mobilePageData)
    {
        if (mobilePageData.getIsExistsList().equals("true")) {
            mobilePageData.getMobilePageTableList().setPageId(mobilePageData.getId());
            mobilePageTableListMapper.updateMobilePageTableListByPageId(mobilePageData.getMobilePageTableList());
        }
        return mobilePageDataMapper.updateMobilePageData(mobilePageData);
    }

    /**
     * 批量删除移动端数据
     * 
     * @param ids 需要删除的移动端数据主键
     * @return 结果
     */
    @Override
    public int deleteMobilePageDataByIds(Long[] ids)
    {
        return mobilePageDataMapper.deleteMobilePageDataByIds(ids);
    }

    /**
     * 删除移动端数据信息
     * 
     * @param id 移动端数据主键
     * @return 结果
     */
    @Override
    @Transactional
    public int deleteMobilePageDataById(Long id)
    {
        MobilePageData mobilePageData = mobilePageDataMapper.selectMobilePageDataById(id);
        if(mobilePageData.getIsExistsList().equals("true")){
            int i = mobilePageTableListMapper.deleteMobilePageTableListByPageId(id);
        }
        return mobilePageDataMapper.deleteMobilePageDataById(id);
    }


    @Override
    @Transactional
    public int updateIsIndex(MobilePageData mobilePageData) {
        //先把等于true的改为false
        int i = mobilePageDataMapper.updateIsIndexFalse(mobilePageData);
        //当前的在改为true
        mobilePageData.setIsIndex("true");
        int i1 = mobilePageDataMapper.updateMobilePageData(mobilePageData);
        return i1;
    }
}
