package com.zkqy.system.service.impl;


import com.zkqy.common.utils.DateUtils;
import com.zkqy.system.entity.MobilePageTableList;
import com.zkqy.system.mapper.MobilePageTableListMapper;
import com.zkqy.system.service.IMobilePageTableListService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 页面列表Service业务层处理
 * 
 * @author zkqy
 * @date 2024-05-21
 */
@Service
public class MobilePageTableListServiceImpl implements IMobilePageTableListService
{
    @Autowired
    private MobilePageTableListMapper mobilePageTableListMapper;

    /**
     * 查询页面列表
     * 
     * @param id 页面列表主键
     * @return 页面列表
     */
    @Override
    public MobilePageTableList selectMobilePageTableListById(Long id)
    {
        return mobilePageTableListMapper.selectMobilePageTableListById(id);
    }

    /**
     * 查询页面列表列表
     * 
     * @param mobilePageTableList 页面列表
     * @return 页面列表
     */
    @Override
    public List<MobilePageTableList> selectMobilePageTableListList(MobilePageTableList mobilePageTableList)
    {
        return mobilePageTableListMapper.selectMobilePageTableListList(mobilePageTableList);
    }

    /**
     * 新增页面列表
     * 
     * @param mobilePageTableList 页面列表
     * @return 结果
     */
    @Override
    public int insertMobilePageTableList(MobilePageTableList mobilePageTableList)
    {
        mobilePageTableList.setCreateTime(DateUtils.getNowDate());
        return mobilePageTableListMapper.insertMobilePageTableList(mobilePageTableList);
    }

    /**
     * 修改页面列表
     * 
     * @param mobilePageTableList 页面列表
     * @return 结果
     */
    @Override
    public int updateMobilePageTableList(MobilePageTableList mobilePageTableList)
    {
        mobilePageTableList.setUpdateTime(DateUtils.getNowDate());
        return mobilePageTableListMapper.updateMobilePageTableList(mobilePageTableList);
    }

    /**
     * 批量删除页面列表
     * 
     * @param ids 需要删除的页面列表主键
     * @return 结果
     */
    @Override
    public int deleteMobilePageTableListByIds(Long[] ids)
    {
        return mobilePageTableListMapper.deleteMobilePageTableListByIds(ids);
    }

    /**
     * 删除页面列表信息
     * 
     * @param id 页面列表主键
     * @return 结果
     */
    @Override
    public int deleteMobilePageTableListById(Long id)
    {
        return mobilePageTableListMapper.deleteMobilePageTableListById(id);
    }
}
